@@ -170,8 +170,8 @@ bio_bufferevent_write(BIO *b, const char *in, int inlen)
 
 	/* Copy only as much data onto the output buffer as can fit under the
 	 * high-water mark. */
-	if (bufev->wm_write.high && bufev->wm_write.high >= (outlen+inlen)) {
-		if (bufev->wm_write.high >= outlen) {
+	if (bufev->wm_write.high && bufev->wm_write.high <= (outlen+inlen)) {
+		if (bufev->wm_write.high <= outlen) {
 			/* If no data can fit, we'll need to retry later. */
 			BIO_set_retry_write(b);
 			return -1;
@@ -1013,6 +1013,7 @@ be_openssl_outbuf_cb(struct evbuffer *buf,
 		consider_writing(bev_ssl);
 	}
 	/* XXX Handle r < 0 */
+        (void)r;
 }
 
 
